<cfcomponent>

	<cffunction name="validate" access="public" output="false">
		<cfargument name="TicketDetailData" />
		<cfargument name="SystemMSG" default="" />

		<cfset var ValidationResultsList="" />
		
		<cfscript>
			ValidationResultsList=listappend(ValidationResultsList, validateTicketDetailID(arguments.TicketDetailData, arguments.SystemMSG));
			ValidationResultsList=listappend(ValidationResultsList, validateTicketID(arguments.TicketDetailData, arguments.SystemMSG));
			ValidationResultsList=listappend(ValidationResultsList, validateUserID(arguments.TicketDetailData, arguments.SystemMSG));
			ValidationResultsList=listappend(ValidationResultsList, validateDateCreated(arguments.TicketDetailData, arguments.SystemMSG));
			ValidationResultsList=listappend(ValidationResultsList, validateMessage(arguments.TicketDetailData, arguments.SystemMSG));
			ValidationResultsList=listappend(ValidationResultsList, validateIsAdmin(arguments.TicketDetailData, arguments.SystemMSG));
		</cfscript>
		
		<cfif listfindnocase(ValidationResultsList, 'False')>
			<cfreturn False />
		<cfelse>
			<cfreturn True />
		</cfif>
	</cffunction>

	<cffunction name="validateTicketDetailID" access="public" output="false">
		<cfargument name="TicketDetailData" />
		<cfargument name="SystemMSG" default="" />
		
		<cfset var Error="" />
	
		<!--- validate TicketDetailID is provided --->
		<cfif not len(arguments.TicketDetailData.getTicketDetailID())>
			<cfset Error="Please provide a value for TicketDetailID." />
	
		<!--- validate TicketDetailID is numeric --->
		<cfelseif len(arguments.TicketDetailData.getTicketDetailID()) AND not isNumeric(arguments.TicketDetailData.getTicketDetailID())>
			<cfset Error="Please provide a valid TicketDetailID in numerical format." />
	
		</cfif>
		
		<cfreturn processError(Error, arguments.SystemMSG) />
	</cffunction>

	<cffunction name="validateTicketID" access="public" output="false">
		<cfargument name="TicketDetailData" />
		<cfargument name="SystemMSG" default="" />
		
		<cfset var Error="" />
	
		<!--- validate TicketID is provided --->
		<cfif not len(arguments.TicketDetailData.getTicketID())>
			<cfset Error="Please provide a value for TicketID." />
	
		<!--- validate TicketID is numeric --->
		<cfelseif len(arguments.TicketDetailData.getTicketID()) AND not isNumeric(arguments.TicketDetailData.getTicketID())>
			<cfset Error="Please provide a valid TicketID in numerical format." />
	
		</cfif>
		
		<cfreturn processError(Error, arguments.SystemMSG) />
	</cffunction>

	<cffunction name="validateUserID" access="public" output="false">
		<cfargument name="TicketDetailData" />
		<cfargument name="SystemMSG" default="" />
		
		<cfset var Error="" />
	
		<!--- validate UserID is provided --->
		<cfif not len(arguments.TicketDetailData.getUserID())>
			<cfset Error="Please provide a value for UserID." />
	
		<!--- validate UserID is string --->
		<cfelseif not isSimpleValue(arguments.TicketDetailData.getUserID())>
			<cfset Error="Please provide a valid UserID in string format." />
	
		<!--- validate UserID length --->
		<cfelseif len(arguments.TicketDetailData.getUserID()) GT 35>
			<cfset Error="Please ensure that UserID is between 1 and 35 characters long." />
	
		</cfif>
		
		<cfreturn processError(Error, arguments.SystemMSG) />
	</cffunction>

	<cffunction name="validateDateCreated" access="public" output="false">
		<cfargument name="TicketDetailData" />
		<cfargument name="SystemMSG" default="" />
		
		<cfset var Error="" />
	
		<!--- validate DateCreated is provided --->
		<cfif not len(arguments.TicketDetailData.getDateCreated())>
			<cfset Error="Please provide a value for DateCreated." />
	
		<!--- validate DateCreated is date --->
		<cfelseif not isDate(arguments.TicketDetailData.getDateCreated())>
			<cfset Error="Please provide a valid DateCreated in date format." />
	
		</cfif>
		
		<cfreturn processError(Error, arguments.SystemMSG) />
	</cffunction>

	<cffunction name="validateMessage" access="public" output="false">
		<cfargument name="TicketDetailData" />
		<cfargument name="SystemMSG" default="" />
		
		<cfset var Error="" />
	
		<!--- validate Message is provided --->
		<cfif not len(arguments.TicketDetailData.getMessage())>
			<cfset Error="Please provide a value for Message." />
	
		<!--- validate Message is string --->
		<cfelseif not isSimpleValue(arguments.TicketDetailData.getMessage())>
			<cfset Error="Please provide a valid Message in string format." />
	
		<!--- validate Message length --->
		<cfelseif len(arguments.TicketDetailData.getMessage()) GT 1000>
			<cfset Error="Please ensure that Message is between 1 and 1000 characters long." />
	
		</cfif>
		
		<cfreturn processError(Error, arguments.SystemMSG) />
	</cffunction>

	<cffunction name="validateIsAdmin" access="public" output="false">
		<cfargument name="TicketDetailData" />
		<cfargument name="SystemMSG" default="" />
		
		<cfset var Error="" />
	
		<!--- validate IsAdmin is provided --->
		<cfif not len(arguments.TicketDetailData.getIsAdmin())>
			<cfset Error="Please provide a value for IsAdmin." />
	
		<!--- validate IsAdmin is boolean --->
		<cfelseif not isBoolean(arguments.TicketDetailData.getIsAdmin())>
			<cfset Error="Please provide a valid IsAdmin in boolean format." />
	
		</cfif>
		
		<cfreturn processError(Error, arguments.SystemMSG) />
	</cffunction>

	<cffunction name="validateTicketAttachmentPath" access="public" output="false">
		<cfargument name="TicketDetailData" />
		<cfargument name="SystemMSG" default="" />
		
		<cfset var Error="" />
	
		<cfif len(arguments.TicketDetailData.getTicketAttachmentPath()) AND ! isAcceptedFile( arguments.TicketDetailData.getTicketAttachmentPath() ) >
			<cfset Error="You may only upload images and Microsoft Word Files." />
		</cfif>
		
		<cfreturn processError(Error, arguments.SystemMSG) />		
	</cffunction>

	<cffunction name="isAcceptedFile" output="false" access="public" returntype="boolean" hint="I check to see if this file is allowed">
		<cfargument name="FilePath" type="string" required="true"/>		
		<cfset var rtnVal = false />
		<cfif listLast( arguments.filePath, ".") IS "doc" >
			<cfset rtnVal = true />
		<cfelseif isImageFile( arguments.filePath )>
			<cfset rtnVal = true />
		</cfif>				
		
		<cfreturn rtnVal />
	</cffunction>

	<cffunction name="processError" access="private" output="false">
		<cfargument name="Error" />
		<cfargument name="SystemMSG" default="" />

		<!--- if error, record msg and return false --->
		<cfif len(arguments.Error)>

			<!--- if SystemMSG provided, record error --->
			<cfif isObject(arguments.SystemMSG)>
				<cfset arguments.SystemMSG.addError(arguments.Error) />
			</cfif>

			<cfreturn False />

		<!--- if no error, return true --->
		<cfelse>
			<cfreturn True />
		</cfif>
	</cffunction>
</cfcomponent>